@@ -40,7 +40,7 @@ NULL
 #'
 diff.MLModel <- function(x, ...) {
   if (!is.trained(x)) stop("no training results to diff")
-  map(function(trainbit) diff(trainbit@performance), x@trainbits)
+  map(function(trainbit) diff(trainbit@performance), x@traininfo)
 }
 
 
