@@ -29,10 +29,10 @@
 #'     approximations to estimated survival curves for predicting survival
 #'     events/probabilities.  Choices are \code{"empirical"} (default) for the
 #'     Kaplan-Meier estimator, \code{"exponential"}, or \code{"weibull"}.}
-#'   \item{\code{grid}}{number of parameter-specific values to generate
-#'     automatically for \link[=TunedModel]{tuning} of models that have
-#'     pre-defined grids or a \code{\link{Grid}} function, function name, or
-#'     call [default: 3].}
+#'   \item{\code{grid}}{\code{size} argument to \code{\link{Grid}} indicating
+#'     the number of parameter-specific values to generate automatically for
+#'     \link[=TunedModel]{tuning} of models that have pre-defined grids or a
+#'     \code{\link{Grid}} function, function name, or call [default: 3].}
 #'   \item{\code{max.print}}{number of models or data rows to show with print
 #'     methods or \code{Inf} to show all [default: 10].}
 #'   \item{\code{method.EmpiricalSurv}}{character string specifying the
@@ -267,7 +267,7 @@ MachineShop_global <- as.environment(list(
         } else {
           result <- try(Grid(x), silent = TRUE)
           if (is(result, "try-error")) {
-            DomainError(x, "must be a positive numeric value or ",
+            DomainError(x, "must be a positive integer value(s) or ",
                            "a Grid function, function name, or call")
           } else result
         }
@@ -325,44 +325,54 @@ MachineShop_global <- as.environment(list(
     ),
 
     metrics.ConfusionMatrix = list(
-      value = c("Accuracy" = "accuracy",
-                "Kappa" = "kappa2",
-                "Weighted Kappa" = "weighted_kappa2",
-                "Sensitivity" = "sensitivity",
-                "Specificity" = "specificity"),
+      value = c(
+        "Accuracy" = "accuracy",
+        "Kappa" = "kappa2",
+        "Weighted Kappa" = "weighted_kappa2",
+        "Sensitivity" = "sensitivity",
+        "Specificity" = "specificity"
+      ),
       check = check_metrics
     ),
 
     metrics.factor = list(
-      value = c("Brier" = "brier",
-                "Accuracy" = "accuracy",
-                "Kappa" = "kappa2",
-                "Weighted Kappa" = "weighted_kappa2",
-                "ROC AUC" = "roc_auc",
-                "Sensitivity" = "sensitivity",
-                "Specificity" = "specificity"),
+      value = c(
+        "Brier" = "brier",
+        "Accuracy" = "accuracy",
+        "Kappa" = "kappa2",
+        "Weighted Kappa" = "weighted_kappa2",
+        "ROC AUC" = "roc_auc",
+        "Sensitivity" = "sensitivity",
+        "Specificity" = "specificity"
+      ),
       check = check_metrics
     ),
 
     metrics.matrix = list(
-      value = c("RMSE" = "rmse",
-                "R2" = "r2",
-                "MAE" = "mae"),
+      value = c(
+        "RMSE" = "rmse",
+        "R2" = "r2",
+        "MAE" = "mae"
+      ),
       check = check_metrics
     ),
 
     metrics.numeric = list(
-      value = c("RMSE" = "rmse",
-                "R2" = "r2",
-                "MAE" = "mae"),
+      value = c(
+        "RMSE" = "rmse",
+        "R2" = "r2",
+        "MAE" = "mae"
+      ),
       check = check_metrics
     ),
 
     metrics.Surv = list(
-      value = c("C-Index" = "cindex",
-                "Brier" = "brier",
-                "ROC AUC" = "roc_auc",
-                "Accuracy" = "accuracy"),
+      value = c(
+        "C-Index" = "cindex",
+        "Brier" = "brier",
+        "ROC AUC" = "roc_auc",
+        "Accuracy" = "accuracy"
+      ),
       check = check_metrics
     ),
 
@@ -458,6 +468,14 @@ MachineShop_global <- as.environment(list(
       }
     ),
 
+    response_types = list(
+      value = c(
+        "binary", "BinomialVariate", "DiscreteVariate", "factor", "matrix",
+        "NegBinomialVariate", "numeric", "ordered", "PoissonVariate", "Surv"
+      ),
+      check = function(x) check_const(x, "response_types")
+    ),
+
     RHS.formula = list(
       value = sort(c(
         ".", "(", ":", "%in%", "I", "offset",
@@ -500,11 +518,13 @@ MachineShop_global <- as.environment(list(
     ),
 
     stats.Resamples = list(
-      value = c("Mean" = "base::mean",
-                "Median" = "stats::median",
-                "SD" = "stats::sd",
-                "Min" = "base::min",
-                "Max" = "base::max"),
+      value = c(
+        "Mean" = "base::mean",
+        "Median" = "stats::median",
+        "SD" = "stats::sd",
+        "Min" = "base::min",
+        "Max" = "base::max"
+      ),
       check = check_stats
     ),
 
