@@ -9,6 +9,6 @@ test_that("model fitting", {
     expect_output(test_model_factor(model))
     expect_output(test_model_numeric(model))
     expect_output(test_model_ordered(model))
-    expect_error(test_model_Surv(model))
+    expect_output(test_model_Surv(model))
   })
 })
