@@ -16,7 +16,7 @@ test_fit <- function(grid) {
         model = TunedModel(RangerModel, grid = grid)),
     "MLModelFit"
   )
-  model_grid <- as.MLModel(model_fit)@trainbits[[1]]@grid$Model
+  model_grid <- as.MLModel(model_fit)@traininfo[[1]]@grid$Model
   nrow(model_grid) && ncol(model_grid) == nrow(grid)
 }
 
@@ -26,32 +26,32 @@ test_that("ParameterGrid construction and model fitting", {
   context("ParameterGrid")
   with_parallel({
 
-    expect_error(ParameterGrid(param_list, length = -1))
+    expect_error(ParameterGrid(param_list, size = -1))
     expect_error(ParameterGrid(param_list, random = 0))
 
     grid <- expect_s4_class(ParameterGrid(param_list), "ParameterGrid")
     expect_true(test_fit(grid))
 
     grid <- expect_s4_class(
-      ParameterGrid(param_list, length = 0),
+      ParameterGrid(param_list, size = 0),
       "ParameterGrid"
     )
     expect_true(test_fit(grid))
 
     grid <- expect_s4_class(
-      ParameterGrid(param_list, length = 2),
+      ParameterGrid(param_list, size = 2),
       "ParameterGrid"
     )
     expect_true(test_fit(grid))
 
     grid <- expect_s4_class(
-      ParameterGrid(param_list, length = c(3, 0, 2)),
+      ParameterGrid(param_list, size = c(3, 0, 2)),
       "ParameterGrid"
     )
     expect_true(test_fit(grid))
 
     grid <- expect_s4_class(
-      ParameterGrid(param_list, length = 2, random = 5),
+      ParameterGrid(param_list, size = 2, random = 5),
       "ParameterGrid"
     )
     expect_true(test_fit(grid))
